@@ -1,5 +1,5 @@
 from math import sqrt
-
+from typing import List
 
 class Layer:
     def __init__(self, name: str):
@@ -58,7 +58,7 @@ class Begin(Layer):
 
 
 class Input(Layer):
-    def __init__(self, pathfile, shape: list[int], to="(0,0,0)", name="temp"):
+    def __init__(self, pathfile, shape: List[int], to="(0,0,0)", name="temp"):
         self.hidden_name = name
         self.pathfile = pathfile
         self.to = to
@@ -224,7 +224,7 @@ class ConvConvRelu(Layer):
 class Pool(Layer):
     def __init__(
         self,
-        shape: list[int],
+        shape: List[int],
         name: str = None,
         offset: str = "(0,0,0)",
         to=None,
